@@ -1,10 +1,16 @@
 #!/usr/local/bin/python2.7
 #
+# This file is part of pyasn1-modules software.
+#
+# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
+# License: http://pyasn1.sf.net/license.html
+#
 # Generate SNMPGET request, parse response
 #
 from pyasn1.codec.ber import encoder, decoder
 from pyasn1_modules import rfc1157
-import sys, socket
+import sys
+import socket
 
 if len(sys.argv) != 4:
     print("""Usage:
@@ -32,6 +38,7 @@ sock.sendto(encoder.encode(msg), (sys.argv[2], 161))
 
 substrate, _ = sock.recvfrom(2048)
 
+# noinspection PyRedeclaration
 rMsg, _ = decoder.decode(substrate, asn1Spec=msg)
 
 print('received: %s' % rMsg.prettyPrint())
